<?php
$this->js_css->parse_js('rtgrid/js/jquery.cookie.js');
$this->js_css->parse_js('rtgrid/js/clone.js');
?>
<?= $form_open ?>
<?php if (count($tabs_control) > 1): ?>
    <ul id="myTab" class="nav nav-tabs">
        <?php foreach ($tabs_control as $tab): ?>
            <li <?= $tab['active'] ?>><a href="#<?= $tab['id'] ?>" data-toggle="tab"><?= $tab['name'] ?></a></li>
        <?php endforeach; ?>
    </ul>
<?php endif; ?>
<div id="myTabContent" class="tab-content">
    <?php if (!empty($message) || $this->session->flashdata('rtgrid_edit_flash_message')) : ?>
        <?= $message . $this->session->flashdata('rtgrid_edit_flash_message') ?>
    <?php endif; ?>
    <?php foreach ($tabs as $tab): ?>
        <div class="tab-pane <?= $tab['active'] ?>" id="<?= $tab['id'] ?>">
            <?= $tab['data'] ?>
        </div>
    <?php endforeach; ?>
</div>
<div class="form-actions">
    <?php foreach ($actions as $val): ?>
        <?= $val['action'] ?>
    <?php endforeach; ?>
</div>
<?= $form_close; ?>