<?php

return[
    'developer_docs' => [
        'pages' => [
            'crud' => [
                'label'    => 'CRUD',
                'file'     => __DIR__ . '/../docs/index.md',
                'position' => 10,
                'pages'    => [
                    'add_action'           => [
                        'label'    => 'add_action',
                        'file'     => __DIR__ . '/../docs/add_action.md',
                        'position' => 110,
                    ],
                    'add_photogallery'     => [
                        'label'    => 'add_photogallery',
                        'file'     => __DIR__ . '/../docs/add_photogallery.md',
                        'position' => 260,
                    ],
                    'add_top_action'       => [
                        'label'    => 'add_top_action',
                        'file'     => __DIR__ . '/../docs/add_top_action.md',
                        'position' => 100,
                    ],
                    'attach'               => [
                        'label'    => 'attach',
                        'file'     => __DIR__ . '/../docs/attach.md',
                        'position' => 170,
                    ],
                    'before_action'        => [
                        'label'    => 'before_action',
                        'file'     => __DIR__ . '/../docs/before_action.md',
                        'position' => 140,
                    ],
                    'callback'             => [
                        'label'    => 'callback',
                        'file'     => __DIR__ . '/../docs/callback.md',
                        'position' => 70,
                    ],
                    'callback_after_edit'  => [
                        'label'    => 'callback_after_edit',
                        'file'     => __DIR__ . '/../docs/callback_after_edit.md',
                        'position' => 160,
                    ],
                    'callback_before_edit' => [
                        'label'    => 'callback_before_edit',
                        'file'     => __DIR__ . '/../docs/callback_before_edit.md',
                        'position' => 150,
                    ],
                    'callback_column'      => [
                        'label'    => 'callback_column',
                        'file'     => __DIR__ . '/../docs/callback_column.md',
                        'position' => 80,
                    ],
                    'callback_field'       => [
                        'label'    => 'callback_field',
                        'file'     => __DIR__ . '/../docs/callback_field.md',
                        'position' => 90,
                    ],
                    'columns'              => [
                        'label'    => 'columns',
                        'file'     => __DIR__ . '/../docs/columns.md',
                        'position' => 40,
                    ],
                    'detach'               => [
                        'label'    => 'detach',
                        'file'     => __DIR__ . '/../docs/detach.md',
                        'position' => 180,
                    ],
                    'display_as'           => [
                        'label'    => 'display_as',
                        'file'     => __DIR__ . '/../docs/display_as.md',
                        'position' => 60,
                    ],
                    'fields'               => [
                        'label'    => 'fields',
                        'file'     => __DIR__ . '/../docs/fields.md',
                        'position' => 50,
                    ],
                    'hidden'               => [
                        'label'    => 'multifield',
                        'file'     => __DIR__ . '/../docs/hidden.md',
                        'position' => 240,
                    ],
                    'multifield'           => [
                        'label'    => 'Установка мультиполей',
                        'file'     => __DIR__ . '/../docs/multifield.md',
                        'position' => 270,
                    ],
                    'crud_multilang'       => [
                        'label'    => 'multilang',
                        'file'     => __DIR__ . '/../docs/multilang.md',
                        'position' => 190,
                    ],
                    'readonly'             => [
                        'label'    => 'readonly',
                        'file'     => __DIR__ . '/../docs/readonly.md',
                        'position' => 230,
                    ],
                    'required_fields'      => [
                        'label'    => 'required_fields',
                        'file'     => __DIR__ . '/../docs/required_fields.md',
                        'position' => 250,
                    ],
                    'set_image_upload'     => [
                        'label'    => 'set_image_upload',
                        'file'     => __DIR__ . '/../docs/set_image_upload.md',
                        'position' => 200,
                    ],
                    'set_order_by'         => [
                        'label'    => 'set_order_by',
                        'file'     => __DIR__ . '/../docs/set_order_by.md',
                        'position' => 30,
                    ],
                    'set_primery_key'      => [
                        'label'    => 'set_primery_key',
                        'file'     => __DIR__ . '/../docs/set_primery_key.md',
                        'position' => 20,
                    ],
                    'set_relation'         => [
                        'label'    => 'set_relation',
                        'file'     => __DIR__ . '/../docs/set_relation.md',
                        'position' => 210,
                    ],
                    'set_relation_n_n'     => [
                        'label'    => 'set_relation_n_n',
                        'file'     => __DIR__ . '/../docs/set_relation_n_n.md',
                        'position' => 220,
                    ],
                    'set_table'            => [
                        'label'    => 'set_table',
                        'file'     => __DIR__ . '/../docs/set_table.md',
                        'position' => 10,
                    ],
                    'unique_fields'        => [
                        'label'    => 'unique_fields',
                        'file'     => __DIR__ . '/../docs/unique_fields.md',
                        'position' => 280,
                    ],
                    'unset_action'         => [
                        'label'    => 'unset_action',
                        'file'     => __DIR__ . '/../docs/unset_action.md',
                        'position' => 130,
                    ],
                    'unset_top_action'     => [
                        'label'    => 'unset_top_action',
                        'file'     => __DIR__ . '/../docs/unset_top_action.md',
                        'position' => 120,
                    ],
                    'tooltip'              => [
                        'label'    => 'tooltip',
                        'file'     => __DIR__ . '/../docs/tooltip.md',
                        'position' => 290,
                    ],
                    'set_flashmessage'    => [
                        'label'    => 'set_flashmessage',
                        'file'     => __DIR__ . '/../docs/set_flashmessage.md',
                        'position' => 300,
                    ],
                ]
            ],
        ]
    ]
];
