<div class="image_upload">
    <?= $img_box ?>
    <?php if (!empty($width) && !empty($height)) : ?>
        <small><?= sprintf($this->lang->line('Image auto resizing (width/height): %spx/%spx'), $width, $height) ?></small>
    <?php endif; ?>
</div>